============
Installation
============

At the command line::

    $ pip install parcelbright

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv parcelbright
    $ pip install parcelbright
